pub struct ExtIdleNotifierV1 { /* private fields */ }Expand description
idle notification manager
This interface allows clients to monitor user idle status.
After binding to this global, clients can create ext_idle_notification_v1 objects to get notified when the user is idle for a given amount of time.
See also the Request enum for this interface.